@@ -17,16 +17,16 @@ from opps.images.generate import image_url
 from redactor.widgets import RedactorEditor
 
 
+@apply_opps_rules('articles')
 class ArticleImageInline(admin.TabularInline):
     model = ArticleImage
     fk_name = 'article'
     raw_id_fields = ['image']
     actions = None
     extra = 1
-    verbose_name = _(u"Article image")
-    verbose_name_plural = _(u"Article images")
-    fieldsets = [(None, {'fields': ('image', 'image_thumb', 'order')})]
-
+    fieldsets = [(None, {'fields': ('image', 'image_thumb',
+                         'order', 'caption')})]
+    ordering = ('order',)
     readonly_fields = ['image_thumb']
 
     def image_thumb(self, obj):
@@ -38,19 +38,20 @@ class ArticleImageInline(admin.TabularInline):
     image_thumb.allow_tags = True
 
 
+@apply_opps_rules('articles')
 class ArticleSourceInline(admin.TabularInline):
     model = ArticleSource
     fk_name = 'article'
     raw_id_fields = ['source']
     actions = None
     extra = 1
-    verbose_name = _(u"Article source")
-    verbose_name_plural = _(u"Article sources")
+    ordering = ('order',)
     fieldsets = [(None, {
         'classes': ('collapse',),
         'fields': ('source', 'order')})]
 
 
+@apply_opps_rules('articles')
 class ArticleBoxArticlesInline(admin.TabularInline):
     model = ArticleBoxArticles
     fk_name = 'articlebox'
@@ -82,6 +83,7 @@ class ArticleAdmin(PublishableAdmin):
         return list_filter
 
 
+@apply_opps_rules('articles')
 class PostRelatedInline(admin.TabularInline):
     model = PostRelated
     fk_name = 'post'
@@ -90,8 +92,6 @@ class PostRelatedInline(admin.TabularInline):
     ordering = ('order',)
     extra = 1
     classes = ('collapse',)
-    verbose_name = (u'Related post')
-    verbose_name_plural = (u'Related posts')
 
 
 @apply_opps_rules('articles')
@@ -106,7 +106,7 @@ class PostAdmin(ArticleAdmin):
                        'short_url')}),
         (_(u'Content'), {
             'fields': ('hat', 'short_title', 'headline', 'content',
-                       ('main_image', 'image_thumb'), 'tags')}),
+                       ('main_image', 'image_thumb'), 'main_image_caption', 'tags')}),
         (_(u'Relationships'), {
             'fields': ('channel', 'albums',)}),
         (_(u'Publication'), {
@@ -129,7 +129,7 @@ class AlbumAdminForm(forms.ModelForm):
 @apply_opps_rules('articles')
 class AlbumAdmin(ArticleAdmin):
     form = AlbumAdminForm
-    inlines = [ArticleImageInline]
+    inlines = [ArticleImageInline, ArticleSourceInline]
     list_display = ['title', 'channel', 'images_count',
                     'date_available', 'published', 'preview_url']
 
@@ -139,7 +139,7 @@ class AlbumAdmin(ArticleAdmin):
                        'short_url',)}),
         (_(u'Content'), {
             'fields': ('hat', 'short_title', 'headline',
-                       ('main_image', 'image_thumb'), 'tags')}),
+                       ('main_image', 'image_thumb'), 'main_image_caption', 'tags')}),
         (_(u'Relationships'), {
             'fields': ('channel',)}),
         (_(u'Publication'), {
@@ -164,7 +164,7 @@ class LinkAdmin(ArticleAdmin):
                        'short_url',)}),
         (_(u'Content'), {
             'fields': ('hat', 'short_title', 'headline', 'url', 'articles',
-                       ('main_image', 'image_thumb'), 'tags')}),
+                       ('main_image', 'image_thumb'), 'main_image_caption', 'tags')}),
         (_(u'Relationships'), {
             'fields': ('channel',)}),
         (_(u'Publication'), {
@@ -209,11 +209,12 @@ class HasQuerySet(SimpleListFilter):
         return queryset
 
 
+@apply_opps_rules('articles')
 class ArticleBoxAdmin(BaseBoxAdmin):
     inlines = [ArticleBoxArticlesInline]
     raw_id_fields = ['channel', 'article', 'queryset']
-    # list_display = ['name', 'channel_name', 'date_available',
-    #                 'is_dynamic', 'published']
+    list_display = ['name', 'channel_name', 'date_available',
+                    'published']
 
     fieldsets = (
         (_(u'Identification'), {
@@ -236,12 +237,10 @@ class ArticleBoxAdmin(BaseBoxAdmin):
     clean_ended_entries.short_description = _(u'Clean ended articles')
 
     def get_list_display(self, request):
+        list_display = getattr(self, 'list_display', [])
         if request.user.is_superuser:
-            return ['name', 'channel_name', 'date_available',
-                    'is_dynamic', 'published']
-        else:
-            return ['name', 'channel_name', 'date_available',
-                    'published']
+            return list_display + ['is_dynamic']
+        return list_display
 
     def get_list_filter(self, request):
         list_filter = super(ArticleBoxAdmin, self).list_filter
