@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+from urlparse import urlparse
+
+from django.conf import settings
 from django.db import models
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
@@ -30,6 +33,18 @@ class Article(Publishable, Slugged):
         _("Short URL"),
         null=True, blank=True,
     )
+    site_iid = models.PositiveIntegerField(
+        _(u"Site id"),
+        max_length=4,
+        null=True, blank=True,
+        db_index=True,
+    )
+    site_domain = models.CharField(
+        _(u"Site domain"),
+        max_length=100,
+        null=True, blank=True,
+        db_index=True,
+    )
     channel = models.ForeignKey(
         'channels.Channel',
         verbose_name=_(u"Channel"),
@@ -64,16 +79,25 @@ class Article(Publishable, Slugged):
         on_delete=models.SET_NULL,
         verbose_name=_(u'Main Image'),
     )
+    main_image_caption = models.CharField(
+        _(u"Main Image Caption"),
+        max_length=255,
+        blank=True,
+        null=True,
+        help_text=_(u'Maximum characters 255'),
+    )
     images = models.ManyToManyField(
         'images.Image',
         null=True, blank=True,
         related_name='article_images',
         through='articles.ArticleImage',
+        verbose_name=_(u'Images')
     )
     sources = models.ManyToManyField(
         'sources.Source',
         null=True, blank=True,
         through='articles.ArticleSource',
+        verbose_name=_(u'Sources')
     )
     tags = TaggableManager(blank=True, verbose_name=u'Tags')
     show_on_root_channel = models.BooleanField(
@@ -91,6 +115,8 @@ class Article(Publishable, Slugged):
         unique_together = ["site", "child_class", "channel_long_slug", "slug"]
 
     def save(self, *args, **kwargs):
+        self.site_domain = self.site.domain
+        self.site_iid = self.site.id
         self.channel_name = self.channel.name
         self.channel_long_slug = self.channel.long_slug
         self.child_class = self.__class__.__name__
@@ -118,27 +144,33 @@ class Article(Publishable, Slugged):
         return _(self.child_class)
 
     def get_http_absolute_url(self):
-        return "http://{}{}".format(self.site.domain, self.get_absolute_url())
+        return "http://{}{}".format(self.site_domain, self.get_absolute_url())
 
     get_http_absolute_url.short_description = 'URL'
 
     def recommendation(self):
+        now = timezone.now()
+        start = now - timezone.timedelta(
+            days=settings.OPPS_RECOMMENDATION_RANGE_DAYS
+        )
+
         cachekey = _cache_key(
             '{}-recommendation'.format(self.__class__.__name__),
-            self.__class__, self.site, u"{}-{}".format(self.channel_long_slug,
-                                                       self.slug))
+            self.__class__, self.site_domain,
+            u"{}-{}".format(self.channel_long_slug, self.slug))
         getcache = cache.get(cachekey)
         if getcache:
             return getcache
 
         tag_list = [t for t in self.tags.all()[:3]]
         _list = [a for a in Article.objects.filter(
+            site_domain=self.site_domain,
             child_class=self.child_class,
             channel_long_slug=self.channel_long_slug,
-            date_available__lte=timezone.now(),
+            date_available__range=(start, now),
             published=True,
             tags__in=tag_list).exclude(
-                pk=self.pk).distinct().all().order_by('pk')[:10]]
+                pk=self.pk).distinct().order_by('-date_available')[:10]]
 
         cache.set(cachekey, _list)
         return _list
@@ -146,21 +178,31 @@ class Article(Publishable, Slugged):
     def all_images(self):
         cachekey = _cache_key(
             '{}-all_images'.format(self.__class__.__name__),
-            self.__class__, self.site, u"{}-{}".format(self.channel_long_slug,
-                                                       self.slug))
+            self.__class__, self.site_domain,
+            u"{}-{}".format(self.channel_long_slug, self.slug))
         getcache = cache.get(cachekey)
         if getcache:
             return getcache
 
+        self.main_image.description = self.main_image_caption
+
         imgs = [self.main_image]
         images = self.images.filter(
             published=True, date_available__lte=timezone.now()
-        ).order_by('articleimage__order', '-date_available')
+        ).order_by('articleimage__order')
 
         if self.main_image:
             images = images.exclude(pk=self.main_image.pk)
         imgs += [i for i in images.distinct()]
 
+        for im in imgs:
+            try:
+                caption = im.articleimage_set.get(article__id=self.id).caption
+                if caption:
+                    im.description = caption
+            except:
+                pass
+
         cache.set(cachekey, imgs)
         return imgs
 
@@ -174,37 +216,51 @@ class Post(Article):
         verbose_name=_(u"Albums")
     )
     related_posts = models.ManyToManyField(
-        'articles.Post',
+        'articles.Article',
         null=True, blank=True,
         related_name='post_relatedposts',
         through='articles.PostRelated',
+        verbose_name=_(u'Related Posts'),
     )
 
-    class META:
+    class Meta:
         verbose_name = _('Post')
         verbose_name_plural = _('Posts')
 
     def all_images(self):
         cachekey = _cache_key(
             '{}main-all_images'.format(self.__class__.__name__),
-            self.__class__, self.site, u"{}-{}".format(self.channel_long_slug,
-                                                       self.slug))
+            self.__class__, self.site_domain,
+            u"{}-{}".format(self.channel_long_slug, self.slug))
         getcache = cache.get(cachekey)
         if getcache:
             return getcache
 
         imgs = super(Post, self).all_images()
-        imgs += [
-            i for a in self.albums.filter(
+
+        album_images = [
+            (i, a) for a in self.albums.filter(
                 published=True,
                 date_available__lte=timezone.now()
             ).distinct()
             for i in a.images.filter(
                 published=True,
                 date_available__lte=timezone.now()
-            ).exclude(pk__in=[i.pk for i in imgs]).distinct()
+            ).exclude(
+                pk__in=[i.pk for i in imgs]
+            ).order_by('articleimage__order').distinct()
         ]
 
+        for im, a in album_images:
+            try:
+                caption = im.articleimage_set.get(article__id=a.id).caption
+                if caption:
+                    im.description = caption
+            except:
+                pass
+
+        imgs += [item[0] for item in album_images]
+
         cache.set(cachekey, imgs)
         return imgs
 
@@ -230,7 +286,7 @@ class PostRelated(models.Model):
         on_delete=models.SET_NULL
     )
     related = models.ForeignKey(
-        'articles.Post',
+        'articles.Article',
         verbose_name=_(u'Related Post'),
         null=True,
         blank=True,
@@ -239,9 +295,9 @@ class PostRelated(models.Model):
     )
     order = models.PositiveIntegerField(_(u'Order'), default=0)
 
-    class META:
-        verbose_name = _('Post related')
-        verbose_name_plural = _('Post relateds')
+    class Meta:
+        verbose_name = _('Related Post')
+        verbose_name_plural = _('Related Posts')
         ordering = ('order',)
 
     def __unicode__(self):
@@ -249,7 +305,8 @@ class PostRelated(models.Model):
 
 
 class Album(Article):
-    class META:
+
+    class Meta:
         verbose_name = _('Album')
         verbose_name_plural = _('Albums')
 
@@ -262,10 +319,11 @@ class Link(Article):
     articles = models.ForeignKey(
         'articles.Article',
         null=True, blank=True,
-        related_name='link_article'
+        related_name='link_article',
+        verbose_name=_(u'Articles')
     )
 
-    class META:
+    class Meta:
         verbose_name = _('Link')
         verbose_name_plural = _('Links')
 
@@ -275,6 +333,16 @@ class Link(Article):
             self.slug
         )
 
+    def is_local(self):
+        try:
+            url = urlparse(self.url)
+            return url.netloc.replace('www', '') == self.site_domain
+        except:
+            return False
+
+    def is_subdomain(self):
+        return self.site_domain in self.url
+
     def clean(self):
         if not self.url and not self.articles:
             raise ValidationError(_('URL field is required.'))
@@ -301,9 +369,10 @@ class ArticleSource(models.Model):
     )
     order = models.PositiveIntegerField(_(u'Order'), default=0)
 
-    class META:
+    class Meta:
         verbose_name = _('Article source')
         verbose_name_plural = _('Article sources')
+        ordering = ('order',)
 
     def __unicode__(self):
         return u"{}".format(self.source.slug)
@@ -324,10 +393,18 @@ class ArticleImage(models.Model):
         on_delete=models.SET_NULL
     )
     order = models.PositiveIntegerField(_(u'Order'), default=0)
+    caption = models.CharField(
+        _(u"Caption"),
+        max_length=255,
+        blank=True,
+        null=True,
+        help_text=_(u'Maximum characters 255')
+    )
 
-    class META:
-        verbose_name = _('Article image')
-        verbose_name_plural = _('Article images')
+    class Meta:
+        verbose_name = _(u'Article image')
+        verbose_name_plural = _(u'Article images')
+        ordering = ('order',)
 
     def __unicode__(self):
         return u"{}".format(self.image.title)
@@ -345,7 +422,8 @@ class ArticleBox(BaseBox):
         'articles.Article',
         null=True, blank=True,
         related_name='articlebox_articles',
-        through='articles.ArticleBoxArticles'
+        through='articles.ArticleBoxArticles',
+        verbose_name=_(u'Articles')
     )
     queryset = models.ForeignKey(
         'boxes.QuerySet',
@@ -354,7 +432,7 @@ class ArticleBox(BaseBox):
         verbose_name=_(u'Query Set')
     )
 
-    class META:
+    class Meta:
         verbose_name = _('Article box')
         verbose_name_plural = _('Articles boxes')
 
@@ -416,9 +494,11 @@ class ArticleConfig(BaseConfig):
     Default implementation
     """
 
-    class META:
+    class Meta:
         verbose_name = _('Article config')
         verbose_name_plural = _('Article configs')
+        permissions = (("developer", "Developer"),)
+        unique_together = ("key_group", "key", "site", "channel", "article")
 
 
 models.signals.post_save.connect(redirect_generate, sender=Link)
