@@ -43,13 +43,24 @@ class QuerySet(Publishable):
         queryset = model.objects.filter(
             published=True,
             date_available__lte=timezone.now())
-        if self.channel:
+
+        try:
+            if model._meta.get_field_by_name('show_on_root_channel'):
+                queryset = queryset.filter(show_on_root_channel=True)
+        except:
+            pass  # silently pass when FieldDoesNotExists
+
+        if self.channel and not self.channel.homepage:
             queryset = queryset.filter(channel=self.channel)
         if self.order == '-':
             queryset = queryset.order_by('-id')
 
         return queryset[:self.limit]
 
+    class Meta:
+        verbose_name = _(u'Queryset')
+        verbose_name_plural = _(u'Querysets')
+
 
 class DynamicBox(BaseBox):
 
@@ -57,3 +68,7 @@ class DynamicBox(BaseBox):
         'boxes.QuerySet',
         verbose_name=_(u'Query Set')
     )
+
+    class Meta:
+        verbose_name = _(u'Dynamic Box')
+        verbose_name_plural = _(u'Dynamic Boxes')
