@@ -20,12 +20,18 @@ class OppsCoreConf(AppConf):
     CHECK_MOBILE = False
     DOMAIN_MOBILE = u''
     PROTOCOL_MOBILE = u'http'
+    DOMAIN_WEB = u''
+    PROTOCOL_WEB = u'http'
     ADMIN_RULES = {}
     RELATED_POSTS_PLACEHOLDER = "---related---"
     CACHE_PREFIX = 'opps'
     CACHE_EXPIRE = 300
+    CACHE_EXPIRE_LIST = 300
+    CACHE_EXPIRE_DETAIL = 300
     RSS_LINK_TEMPLATE = '<a href="{}" class="ir ico ico-rss">RSS</a>'
     LIST_MODELS = ('Post',)
+    RECOMMENDATION_RANGE_DAYS = 180
+    SMART_SLUG_ENABLED = True
 
     class Meta:
         prefix = 'opps'
@@ -39,8 +45,6 @@ class StaticSiteMapsConf(AppConf):
 
 
 class HaystackConf(AppConf):
-    SITECONF = 'opps.search'
-    SEARCH_ENGINE = 'dummy'
 
     class Meta:
         prefix = 'haystack'
