@@ -24,8 +24,9 @@ class Date(models.Model):
 
 class Publishable(Date):
 
-    user = models.ForeignKey(settings.AUTH_USER_MODEL)
-    site = models.ForeignKey(Site, default=1)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL,
+                             verbose_name=_(u'User'))
+    site = models.ForeignKey(Site, default=1, verbose_name=_(u'Site'))
     date_available = models.DateTimeField(_(u"Date available"),
                                           default=timezone.now,
                                           null=True,
@@ -52,7 +53,10 @@ class Slugged(models.Model):
         max_length=150,
     )
 
-    def clean(self):
+    def clean(self, *args, **kwargs):
+
+        self.validate_slug()
+
         if hasattr(self, 'get_absolute_url'):
             try:
                 path = self.get_absolute_url()
@@ -70,10 +74,45 @@ class Slugged(models.Model):
                 )
 
         try:
-            super(Slugged, self).clean()
+            super(Slugged, self).clean(*args, **kwargs)
         except AttributeError:
             pass  # does not implement the clean method
 
+    def validate_slug(self):
+        slug = getattr(self, 'slug', None)
+
+        try:
+            channel = getattr(self, 'channel', None)
+        except:
+            channel = None
+
+        site = getattr(self, 'site', None)
+        if settings.OPPS_SMART_SLUG_ENABLED:
+            filters = {'slug__startswith': slug, 'site': site}
+        else:
+            filters = {'slug': slug, 'site': site}
+
+        if channel:
+            filters['channel'] = channel
+
+        slug_exists = self.__class__.objects.filter(**filters)
+
+        if getattr(self, 'pk', None) is not None:
+            slug_exists = slug_exists.exclude(pk=self.pk)
+
+        if settings.OPPS_SMART_SLUG_ENABLED:
+            if slug_exists:
+                last = slug_exists.latest('slug').slug
+                suffix = last.split('-')[-1]
+                if suffix.isdigit():
+                    suffix = int(suffix) + 1
+                    self.slug = "{0}-{1}".format(self.slug, suffix)
+                else:
+                    self.slug = "{0}-1".format(self.slug)
+        else:
+            if slug_exists.exists():
+                raise ValidationError(_(u"URL already exists."))
+
     def save(self, *args, **kwargs):
         if hasattr(self, 'get_absolute_url'):
             model = self.__class__
@@ -106,12 +145,14 @@ class BaseBox(Publishable):
         'articles.Article',
         null=True, blank=True,
         help_text=_(u'Only published article'),
-        on_delete=models.SET_NULL
+        on_delete=models.SET_NULL,
+        verbose_name=_(u'Article'),
     )
     channel = models.ForeignKey(
         'channels.Channel',
         null=True, blank=True,
-        on_delete=models.SET_NULL
+        on_delete=models.SET_NULL,
+        verbose_name=_(u'Channel'),
     )
     channel_name = models.CharField(
         _(u"Channel name"),
@@ -185,12 +226,14 @@ class BaseConfig(Publishable):
         'articles.Article',
         null=True, blank=True,
         help_text=_(u'Only published article'),
-        on_delete=models.SET_NULL
+        on_delete=models.SET_NULL,
+        verbose_name=_(u'Article'),
     )
     channel = models.ForeignKey(
         'channels.Channel',
         null=True, blank=True,
-        on_delete=models.SET_NULL
+        on_delete=models.SET_NULL,
+        verbose_name=_(u'Channel'),
     )
 
     class Meta:
